# Security Policy

## Supported Versions

| Version | Supported |
|---------|-----------|
| 0.11.x  | ✅         |
| < 0.11  | ❌         |

## Reporting a Vulnerability

If you discover a security vulnerability, please **do not** open a public issue.

Instead, email **baobab00@users.noreply.github.com** with:

1. Description of the vulnerability
2. Steps to reproduce
3. Potential impact

We will respond within **72 hours** and work with you to resolve the issue before any public disclosure.
